@@ -1834,34 +1834,13 @@ def scatter_alex(d, i=0, **kwargs):
     plt.xlim(-0.2, 1.2); plt.ylim(-0.2, 1.2)
 
 
-## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #  High-level plot wrappers
-## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-
-def dplot_48ch(d, func, sharex=True, sharey=True, layout='horiz',
-               pgrid=True, figsize=None, AX=None, nosuptitle=False,
-               scale=True, **kwargs):
-    """Plot wrapper for 48-spot measurements. Use `dplot` instead."""
-    msg = "Wrong layout '%s'. Valid values: 'horiz', 'vert', '6x4'."
-    assert (layout.startswith('vert') or layout.startswith('horiz') or
-            layout == '8x6'), (msg % layout)
-    global gui_status
-    iter_ch = range(48)
-    top_adjust = 0.95
-    if layout == '8x6':
-        nrows, ncols = 6, 8
-        if figsize is None:
-            figsize = (20, 16)
-    else:
-        nrows, ncols = 4, 12
-        if layout.startswith('vert'):
-            nrows, ncols = ncols, nrows
-            iter_ch = np.arange(48).reshape(4, 12).T.ravel()
-        if figsize is None:
-            figsize = (20, 7)
-            if layout.startswith('vert'):
-                figsize = figsize[1], figsize[0]
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
+def _iter_plot(d, func, kwargs, iter_ch, nrows, ncols, figsize, AX,
+               sharex, sharey, suptitle, grid, scale,
+               top_adjust=0.95, hspace=0.15, left=0.08, right=0.96):
     if AX is None:
         fig, AX = plt.subplots(nrows, ncols, figsize=figsize, sharex=sharex,
                                sharey=sharey, squeeze=False)
@@ -1875,15 +1854,15 @@ def dplot_48ch(d, func, sharex=True, sharey=True, layout='horiz',
     for i, ich in enumerate(iter_ch):
         b = d.mburst[ich] if 'mburst' in d else None
         ax = AX.ravel()[i]
-        if i == 0 and not nosuptitle:
+        if i == 0 and suptitle:
             fig.suptitle(d.status())
-        s = u'[%d]' % (ich + 1)
+        s = '[%d]' % ich
         if 'bg_mean' in d:
             s += (' BG=%.1fk' % (d.bg_mean[Ph_sel('all')][ich] * 1e-3))
         if b is not None:
             s += (', #bu=%d' % b.num_bursts)
         ax.set_title(s)
-        ax.grid(pgrid)
+        ax.grid(grid)
         plt.sca(ax)
         gui_status['first_plot_in_figure'] = (i == 0)
         func(d, ich, **kwargs)
@@ -1910,6 +1889,49 @@ def dplot_48ch(d, func, sharex=True, sharey=True, layout='horiz',
     return AX
 
 
+def dplot_48ch(d, func, sharex=True, sharey=True, layout='horiz',
+               grid=True, figsize=None, AX=None, suptitle=True,
+               scale=True, top_adjust=0.95, **kwargs):
+    """Plot wrapper for 48-spot measurements. Use `dplot` instead."""
+    msg = "Wrong layout '%s'. Valid values: 'horiz', 'vert', '8x6'."
+    assert (layout.startswith('vert') or layout.startswith('horiz') or
+            layout == '8x6'), (msg % layout)
+    global gui_status
+    iter_ch = range(48)
+    if layout == '8x6':
+        nrows, ncols = 6, 8
+        if figsize is None:
+            figsize = (20, 16)
+    else:
+        nrows, ncols = 4, 12
+        if layout.startswith('vert'):
+            nrows, ncols = ncols, nrows
+            iter_ch = np.arange(48).reshape(4, 12).T.ravel()
+        if figsize is None:
+            figsize = (20, 7)
+            if layout.startswith('vert'):
+                figsize = figsize[1], figsize[0]
+    return _iter_plot(d, func, kwargs, iter_ch, nrows, ncols, figsize, AX,
+                      sharex, sharey, suptitle, grid, scale,
+                      top_adjust=top_adjust, hspace=0.15, left=0.08, right=0.96)
+
+
+def dplot_16ch(d, func, sharex=True, sharey=True, ncols=8,
+               pgrid=True, figsize=None, AX=None, suptitle=True,
+               scale=True, top_adjust=0.93, **kwargs):
+    """Plot wrapper for 16-spot measurements. Use `dplot` instead."""
+    assert (ncols <= 16), '`ncols` needs to be <= 16.'
+    global gui_status
+    iter_ch = range(16)
+    nrows = int(np.ceil(d.nch / ncols))
+    if figsize is None:
+        subplotsize = (3, 3)
+        figsize = (subplotsize[0] * ncols, subplotsize[1] * nrows)
+    return _iter_plot(d, func, kwargs, iter_ch, nrows, ncols, figsize, AX,
+                      sharex, sharey, suptitle, grid, scale,
+                      top_adjust=top_adjust, hspace=0.15, left=0.08, right=0.96)
+
+
 def dplot_8ch(d, func, sharex=True, sharey=True,
               pgrid=True, figsize=(12, 9), nosuptitle=False, AX=None,
               scale=True, **kwargs):
@@ -1994,6 +2016,8 @@ def dplot(d, func, **kwargs):
         return dplot_1ch(d=d, func=func, **kwargs)
     elif d.nch == 8:
         return dplot_8ch(d=d, func=func, **kwargs)
+    elif d.nch == 16:
+        return dplot_16ch(d=d, func=func, **kwargs)
     elif d.nch == 48:
         return dplot_48ch(d=d, func=func, **kwargs)
 
